summaryrefslogtreecommitdiffstats
path: root/dilos/dependencies/tqt3/debian/maintain
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2024-11-04 13:04:30 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2024-11-04 13:31:16 +0900
commit2b8fd47f124fb980fbcaf6a1def412782d20490b (patch)
treeb997e99e1a009bc814c4118e027515d5dc6bd857 /dilos/dependencies/tqt3/debian/maintain
parent78f8fb896f6c763e59f0e7a4e41c62534caf2071 (diff)
downloadtde-packaging-2b8fd47f124fb980fbcaf6a1def412782d20490b.tar.gz
tde-packaging-2b8fd47f124fb980fbcaf6a1def412782d20490b.zip
DEB tqt3: rename qmake to tqmakedeb/tqt3/tqmake
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
Diffstat (limited to 'dilos/dependencies/tqt3/debian/maintain')
-rw-r--r--dilos/dependencies/tqt3/debian/maintain/build-examples.sh14
1 files changed, 7 insertions, 7 deletions
diff --git a/dilos/dependencies/tqt3/debian/maintain/build-examples.sh b/dilos/dependencies/tqt3/debian/maintain/build-examples.sh
index ed29d712b..97426d69e 100644
--- a/dilos/dependencies/tqt3/debian/maintain/build-examples.sh
+++ b/dilos/dependencies/tqt3/debian/maintain/build-examples.sh
@@ -3,33 +3,33 @@
BUILDDIR=$PWD
export QTDIR=/usr/share/tqt3
-# first copy over the libtqt-mt.so build configuration of .qmake.cache
-cp /usr/share/tqt3/.qmake.cache ./.qmake.cache
+# first copy over the libtqt-mt.so build configuration of .tqmake.cache
+cp /usr/share/tqt3/.tqmake.cache ./.tqmake.cache
# Now compile the examples. The themes example
# won't work since tqconfig.h is not really correct with the
# ifdef's for the TQT_NO_xyz_STYLE, so we use make -k to continue
-cd examples; qmake -o Makefile examples.pro; make -k
+cd examples; tqmake -o Makefile examples.pro; make -k
# Now compile the tutorial.
-cd $BUILDDIR/tutorial; qmake -o Makefile tutorial.pro; make
+cd $BUILDDIR/tutorial; tqmake -o Makefile tutorial.pro; make
# Then the designer examples.
cd $BUILDDIR/tools/designer/examples
for a in `find . -type d -maxdepth 1 -mindepth 1`; do
- cd $a && qmake -o Makefile $a.pro; make; cd ..;
+ cd $a && tqmake -o Makefile $a.pro; make; cd ..;
done
# There is a bigger sql example in book/ with more subdirectories:
cd book
for a in `find . -type d -maxdepth 1 -mindepth 1`; do
- cd $a && qmake -o Makefile $a.pro; make; cd ..;
+ cd $a && tqmake -o Makefile $a.pro; make; cd ..;
done
# Finally, build the linguist tutorials:
cd $BUILDDIR/tools/linguist/tutorial
for a in `find . -type d -maxdepth 1 -mindepth 1`; do
- cd $a && qmake -o Makefile $a.pro; make; cd ..;
+ cd $a && tqmake -o Makefile $a.pro; make; cd ..;
done
# Return to the build directory